@@ -1,6 +1,6 @@
 """fastapi_microsoft_identity - Azure AD authentication for Fast API"""
 
-__version__ = '0.1.0'
+__version__ = '0.1.2'
 __author__ = 'Christos Matskas <christos.matskas@microsoft.com>'
 __all__ = []
-from .auth_service import initialize, AuthError, validate_scope, requires_auth
+from .auth_service import initialize, AuthError, validate_scope, requires_auth, requires_b2c_auth
